import { RevertableEvent } from "@skeldjs/events";
import { RepairSystemMessage } from "@skeldjs/protocol";
import { RoomEvent } from "../RoomEvent";
import { Hostable } from "../../Hostable";
import { PlayerData } from "../../PlayerData";
import { SwitchSystem } from "../../systems";
import { ProtocolEvent } from "../ProtocolEvent";
import { ElectricalEvent } from "./ElectricalEvent";
/**
 * Emitted when a player flips a switch while Electrical is sabotaged.
 */
export declare class ElectricalSwitchFlipEvent<RoomType extends Hostable = Hostable> extends RevertableEvent implements RoomEvent, ElectricalEvent, ProtocolEvent {
    readonly room: RoomType;
    readonly switchsystem: SwitchSystem<RoomType>;
    readonly message: RepairSystemMessage | undefined;
    /**
     * The player that flipped the switch. Only available if the client is
     * the host.
     */
    readonly player: PlayerData<RoomType> | undefined;
    /**
     * The ID of the switch that was flipped (from left-to-right, starting at 0).
     */
    readonly switchId: number;
    /**
     * Whether this switch is flipped.
     */
    readonly flipped: boolean;
    static eventName: "electrical.switchflip";
    eventName: "electrical.switchflip";
    private _alteredSwitchId;
    private _alteredFlipped;
    constructor(room: RoomType, switchsystem: SwitchSystem<RoomType>, message: RepairSystemMessage | undefined, 
    /**
     * The player that flipped the switch. Only available if the client is
     * the host.
     */
    player: PlayerData<RoomType> | undefined, 
    /**
     * The ID of the switch that was flipped (from left-to-right, starting at 0).
     */
    switchId: number, 
    /**
     * Whether this switch is flipped.
     */
    flipped: boolean);
    /**
     * The ID of the alternate switch to flip, if changed.
     */
    get alteredSwitchId(): number;
    /**
     * The alternate value of the switch, if changed.
     */
    get alteredFlipped(): boolean;
    /**
     * Change the switch that was flipped.
     * @param switchId The ID of the switch to flip (from left-to-right, starting at 0).
     */
    setSwitchId(switchId: number): void;
    /**
     * Set whether the switch is flipped.
     * @param flipped Whether the switch is flipped.
     */
    setFlipped(flipped: boolean): void;
}
//# sourceMappingURL=SwitchFlip.d.ts.map